summaryrefslogtreecommitdiff
path: root/sd/source/ui/inc
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/inc')
-rw-r--r--sd/source/ui/inc/AccessibleDocumentViewBase.hxx4
-rw-r--r--sd/source/ui/inc/ClientView.hxx2
-rw-r--r--sd/source/ui/inc/GraphicViewShell.hxx3
-rw-r--r--sd/source/ui/inc/OutlineViewShell.hxx1
-rw-r--r--sd/source/ui/inc/SlideSorterViewShell.hxx2
-rw-r--r--sd/source/ui/inc/ViewShell.hxx2
-rw-r--r--sd/source/ui/inc/framework/Pane.hxx2
-rw-r--r--sd/source/ui/inc/fupoor.hxx2
-rw-r--r--sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx6
9 files changed, 12 insertions, 12 deletions
diff --git a/sd/source/ui/inc/AccessibleDocumentViewBase.hxx b/sd/source/ui/inc/AccessibleDocumentViewBase.hxx
index 24916f6ab0b8..ef4c08b2c11b 100644
--- a/sd/source/ui/inc/AccessibleDocumentViewBase.hxx
+++ b/sd/source/ui/inc/AccessibleDocumentViewBase.hxx
@@ -132,9 +132,9 @@ public:
//===== IAccessibleViewForwarderListener ================================
/** A view forwarder change is signalled for instance when any of the
- window events is received. Thus, instead of overloading the four
+ window events is received. Thus, instead of overriding the four
windowResized... methods it will be sufficient in most cases just to
- overload this method.
+ override this method.
*/
virtual void ViewForwarderChanged (ChangeType aChangeType,
const IAccessibleViewForwarder* pViewForwarder) SAL_OVERRIDE;
diff --git a/sd/source/ui/inc/ClientView.hxx b/sd/source/ui/inc/ClientView.hxx
index 48357380557b..c2713af809f3 100644
--- a/sd/source/ui/inc/ClientView.hxx
+++ b/sd/source/ui/inc/ClientView.hxx
@@ -42,7 +42,7 @@ public:
virtual void CompleteRedraw(OutputDevice* pOutDev, const vcl::Region& rReg, sdr::contact::ViewObjectContactRedirector* pRedirector = 0L) SAL_OVERRIDE;
/* if the view should not do a Invalidate() on the windows, you have to
- overload the following two methods and do something different */
+ override the following two methods and do something different */
virtual void InvalidateOneWin(::vcl::Window& rWin) SAL_OVERRIDE;
virtual void InvalidateOneWin(::vcl::Window& rWin, const Rectangle& rRect) SAL_OVERRIDE;
};
diff --git a/sd/source/ui/inc/GraphicViewShell.hxx b/sd/source/ui/inc/GraphicViewShell.hxx
index fc127e908534..7077e3714568 100644
--- a/sd/source/ui/inc/GraphicViewShell.hxx
+++ b/sd/source/ui/inc/GraphicViewShell.hxx
@@ -64,8 +64,7 @@ public:
virtual ~GraphicViewShell (void);
- /** This method is overloaded in order to have the layer mode always
- active.
+ /** Override this method in order to have the layer mode always active.
*/
virtual void ChangeEditMode (EditMode eMode, bool bIsLayerModeActive) SAL_OVERRIDE;
diff --git a/sd/source/ui/inc/OutlineViewShell.hxx b/sd/source/ui/inc/OutlineViewShell.hxx
index b35833fe8983..1a737b5c65e0 100644
--- a/sd/source/ui/inc/OutlineViewShell.hxx
+++ b/sd/source/ui/inc/OutlineViewShell.hxx
@@ -90,6 +90,7 @@ public:
void ExecCtrl(SfxRequest &rReq);
void GetCtrlState(SfxItemSet &rSet);
+ // FIXME non-virtual override???
void GetMenuState(SfxItemSet &rSet);
void GetAttrState(SfxItemSet &rSet);
void GetState (SfxItemSet& rSet);
diff --git a/sd/source/ui/inc/SlideSorterViewShell.hxx b/sd/source/ui/inc/SlideSorterViewShell.hxx
index e35b1eb1e36e..4f6e7abd5054 100644
--- a/sd/source/ui/inc/SlideSorterViewShell.hxx
+++ b/sd/source/ui/inc/SlideSorterViewShell.hxx
@@ -188,7 +188,7 @@ protected:
virtual SvBorder GetBorder (bool bOuterResize);
- /** This method is overloaded to handle a missing tool bar correctly.
+ /** Override this method to handle a missing tool bar correctly.
This is the case when the slide sorter is not the main view shell.
*/
virtual ::svl::IUndoManager* ImpGetUndoManager (void) const SAL_OVERRIDE;
diff --git a/sd/source/ui/inc/ViewShell.hxx b/sd/source/ui/inc/ViewShell.hxx
index ff43e50132f5..8aa15c43b290 100644
--- a/sd/source/ui/inc/ViewShell.hxx
+++ b/sd/source/ui/inc/ViewShell.hxx
@@ -289,7 +289,7 @@ public:
virtual void VisAreaChanged(const Rectangle& rRect);
/** Create an accessible object representing the specified window.
- Overload this method to provide view mode specific objects. The
+ Override this method to provide view mode specific objects. The
default implementation returns an empty reference.
@param pWindow
Make the document displayed in this window accessible.
diff --git a/sd/source/ui/inc/framework/Pane.hxx b/sd/source/ui/inc/framework/Pane.hxx
index 51992e82cf87..b4ee242f32bf 100644
--- a/sd/source/ui/inc/framework/Pane.hxx
+++ b/sd/source/ui/inc/framework/Pane.hxx
@@ -139,7 +139,7 @@ protected:
::com::sun::star::uno::Reference<com::sun::star::awt::XWindow> mxWindow;
::com::sun::star::uno::Reference<com::sun::star::rendering::XCanvas> mxCanvas;
- /** Overload this method, not getCanvas(), when you want to provide a
+ /** Override this method, not getCanvas(), when you want to provide a
different canvas.
*/
virtual ::com::sun::star::uno::Reference<com::sun::star::rendering::XCanvas>
diff --git a/sd/source/ui/inc/fupoor.hxx b/sd/source/ui/inc/fupoor.hxx
index b86905753fb3..50261d972616 100644
--- a/sd/source/ui/inc/fupoor.hxx
+++ b/sd/source/ui/inc/fupoor.hxx
@@ -106,7 +106,7 @@ public:
// #i33136#
/** Decide if the object to be created should be created
orthogonal. Default implementation uses nSlotID
- to decide. May be overloaded to use other criteria
+ to decide. May be overridden to use other criteria
for this decision
@returns true if the to be created object should be orthogonal.
diff --git a/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx b/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx
index 797b7545a3fc..5c1111f5e06b 100644
--- a/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx
+++ b/sd/source/ui/inc/taskpane/TaskPaneTreeNode.hxx
@@ -129,13 +129,13 @@ public:
*/
virtual TaskPaneShellManager* GetShellManager (void);
- /** You will rarely need to overload this method. To supply your own
- accessible object you should overload CreateAccessible() instead.
+ /** You will rarely need to override this method. To supply your own
+ accessible object you should override CreateAccessible() instead.
*/
virtual ::com::sun::star::uno::Reference<
::com::sun::star::accessibility::XAccessible> GetAccessibleObject (void);
/** Overload this method in order to supply a class specific accessible
object.
The default implementation will return a new instance of
AccessibleTreeNode.
@@ -129,13 +129,13 @@ public:
virtual ::com::sun::star::uno::Reference<
::com::sun::star::accessibility::XAccessible> GetAccessibleObject (void);
- /** Overload this method in order to supply a class specific accessible
+ /** Override this method in order to supply a class specific accessible
object.
The default implementation will return a new instance of